@@ -1,10 +1,10 @@
-from numpy import isin
 import pandas
 import re
 
 from .kwic import KWIC
 from .collocates import Collocates
 from .sentences import Sentences
+from .vocabdist import VocabDist
 
 class SearchResults:
     def __init__(self, filename, search_string, word_count, **kwargs):
@@ -322,6 +322,11 @@ class SearchResults:
             pass
             # TODO: This is where a user could input ['Book of Mormon/1 Nephi/1/1'] to specify exact citation filtering.
 
+    ### VOCABULARY DISTRIBUTION HANDLER
+    def vocab_distribution(self, **kwargs):
+        group_by = kwargs['group_by'] if 'group_by' in kwargs else 0
+        return VocabDist(self.filename, group_by, self.results_indices, self.punct_pos, self.search_string)
+
     ### KWIC LINES HANDLER
     def kwic_lines(self, before=5, after=5, group_by='lower'):
         return KWIC(self.filename, self.results_indices, before=before, after=after, group_by=group_by, search_string=self.search_string, punct_pos=self.punct_pos)
